@@ -1,3 +1,7 @@
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdio.h>
 
 #include "log4c.h"
@@ -19,5 +23,5 @@ int main(int argc, char** argv){
       printf("log4c_fini() failed");
     }
   }
-  return 0;
+  return rc;
 }
