@@ -1,4 +1,4 @@
-/* $Id: defs.h,v 1.3 2003/09/12 21:06:45 legoater Exp $
+/* $Id: defs.h,v 1.4 2013/09/29 17:41:39 valtri Exp $
  *
  * Copyright 2001-2003, Meiosys (www.meiosys.com). All rights reserved.
  *
@@ -16,4 +16,12 @@
 # define __SD_END_DECLS
 #endif
 
+/* GNU C attribute feature,
+ * for the public API macro LOG4C_ATTRIBUTE is used instead */
+#ifdef __GNUC__
+#define SD_ATTRIBUTE(X) __attribute__(X)
+#else
+#define SD_ATTRIBUTE(X)
+#endif
+
 #endif
