@@ -1,10 +1,13 @@
-static const char version[] = "$Id$";
+static const char version[] = "$Id: sprintf.c,v 1.6 2012/10/04 22:51:28 valtri Exp $";
 
 /* 
  * Copyright 2001-2003, Meiosys (www.meiosys.com). All rights reserved.
  *
  * See the COPYING file for the terms of usage and distribution.
  */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -32,9 +35,13 @@ extern char* sd_vsprintf(const char* a_fmt, va_list a_args)
 {
     int		size	= 1024;
     char*	buffer  = sd_calloc(size, sizeof(char));
+    va_list ap;
+    int n;
     
     while (1) {
-	int n = vsnprintf(buffer, size, a_fmt, a_args);
+	va_copy(ap, a_args);
+	n = vsnprintf(buffer, size, a_fmt, ap);
+	va_end(ap);
 	
 	/* If that worked, return */
 	if (n > -1 && n < size)
